@@ -104,9 +104,11 @@ class HashtagMixin:
         """
         try:
             hashtag = self.hashtag_info_a1(name)
-        except Exception as e:
-            if not isinstance(e, ClientError):
-                self.logger.exception(e)
+        except Exception:
+            # Users do not understand the output of such information and create bug reports
+            # such this - https://github.com/adw0rd/instagrapi/issues/364
+            # if not isinstance(e, ClientError):
+            #     self.logger.exception(e)
             hashtag = self.hashtag_info_v1(name)
         return hashtag
 
