@@ -439,7 +439,7 @@ class MediaMixin:
             end_cursor=None
     ) -> Tuple[List[Media], str]:
         """
-        Get a user's media by Public Graphql API
+        Get a page of a user's media by Public Graphql API
 
         Parameters
         ----------
@@ -448,11 +448,12 @@ class MediaMixin:
             Maximum number of media to return, default is 0 (all medias)
         sleep: int, optional
             Timeout between pages iterations, default is 2
-
+        end_cursor: str, optional
+            Cursor value to start at, obtained from previous call to this method
         Returns
         -------
-        List[Media]
-            A list of objects of Media
+        Tuple[List[Media], str]
+            A tuple containing a list of medias and the next end_cursor value
         """
         amount = int(amount)
         user_id = int(user_id)
@@ -525,8 +526,23 @@ class MediaMixin:
             medias = medias[:amount]
         return medias
 
+    def user_medias_paginated_v1(self, user_id: int, amount: int = 0, end_cursor: str = "") -> Tuple[List[Media], str]:
+        """
+        Get a page of user's media by Private Mobile API
 
-    def user_medias_paginated_v1(self, user_id: int, amount: int = 0, end_cursor="") -> Tuple[List[Media], str]:
+        Parameters
+        ----------
+        user_id: int
+        amount: int, optional
+            Maximum number of media to return, default is 0 (all medias)
+        end_cursor: str, optional
+            Cursor value to start at, obtained from previous call to this method
+
+        Returns
+        -------
+        Tuple[List[Media], str]
+            A tuple containing a list of medias and the next end_cursor value
+        """
         amount = int(amount)
         user_id = int(user_id)
         medias = []
@@ -575,7 +591,11 @@ class MediaMixin:
         min_timestamp = None
         while True:
             try:
-                medias_page, next_max_id = self.user_medias_paginated_v1(user_id, amount)
+                medias_page, next_max_id = self.user_medias_paginated_v1(
+                    user_id,
+                    amount,
+                    end_cursor=next_max_id
+                )
             except Exception as e:
                 self.logger.exception(e)
                 break
@@ -589,7 +609,23 @@ class MediaMixin:
             medias = medias[:amount]
         return medias
 
-    def user_medias_paginated(self, user_id: int, amount: int = 0, end_cursor="") -> Tuple[List[Media], str]:
+    def user_medias_paginated(self, user_id: int, amount: int = 0, end_cursor: str = "") -> Tuple[List[Media], str]:
+        """
+        Get a page of user's media
+
+        Parameters
+        ----------
+        user_id: int
+        amount: int, optional
+            Maximum number of media to return, default is 0 (all medias)
+        end_cursor: str, optional
+            Cursor value to start at, obtained from previous call to this method
+
+        Returns
+        -------
+        Tuple[List[Media], str]
+            A tuple containing a list of medias and the next end_cursor value
+        """
 
         class EndCursorIsV1(Exception):
             pass
@@ -610,7 +646,7 @@ class MediaMixin:
             elif not isinstance(e, ClientError):
                 self.logger.exception(e)
             medias, end_cursor = self.user_medias_paginated_v1(user_id, amount, end_cursor=end_cursor)
-        return (medias, end_cursor)
+        return medias, end_cursor
 
     def user_medias(self, user_id: int, amount: int = 0) -> List[Media]:
         """
