@@ -289,3 +289,38 @@ class StoryMixin:
             response.raw.decode_content = True
             shutil.copyfileobj(response.raw, f)
         return path.resolve()
+
+    def story_viewers(self, story_pk: int, amount: int = 20) -> List[UserShort]:
+        """
+        List of users (Private API)
+
+        Parameters
+        ----------
+        story_pk: int
+        amount: int, optional
+            Maximum number of story viewers
+
+        Returns
+        -------
+        List[UserShort]
+            A list of objects of UserShort
+        """
+        users = []
+        next_max_id = None
+        story_pk = self.media_pk(story_pk)
+        import pudb;pudb.set_trace()
+        params = {"supported_capabilities_new": json.dumps(config.SUPPORTED_CAPABILITIES)}
+        while True:
+            try:
+                result = self.private_request(f"media/{story_pk}/list_reel_media_viewer/", params=params)
+                for item in result['users']:
+                    users.append(extract_user_short(item))
+                next_max_id = result.get('next_max_id')
+                if not next_max_id:
+                    break
+            except Exception as e:
+                self.logger.exception(e)
+                break
+        if amount:
+            users = users[:int(amount)]
+        return users
